@@ -32,7 +32,10 @@ if [ -d /run/network ]; then
 					if [ ! -d /sys/class/net/$i ]; then
 						brctl addbr $i
 					fi
-					brctl addif $i $port && ip link set dev $port up
+					brctl addif $i $port && ip link set dev $port up &&
+					if [ "$(ifquery "$i"|sed -n -e's/^bridge[_-]hw: //p')" = "$port" ]; then
+						ip link set dev "$i" address "$(ip link show dev "$port" 2>/dev/null|sed -n "s|.*link/ether \([^ ]*\) brd.*|\1|p")"
+					fi
 				fi
 				break
 				;;
