@@ -25,6 +25,11 @@ case "$IF_BRIDGE_PORTS" in
 	;;
 esac
 
+# Overload bridge_hw, now it can be a device as well as an address
+# The device can exist or not, then it is emptied
+if [ "$IF_BRIDGE_HW" ] && ! echo "$IF_BRIDGE_HW"|grep -q "..:..:..:..:..:.."; then
+  IF_BRIDGE_HW="$(ip link show dev "$IF_BRIDGE_HW" 2>/dev/null|sed -n "s|.*link/ether \([^ ]*\) brd.*|\1|p")"
+fi
 # Previous work (create the interface)
 if [ "$MODE" = "start" ] && [ ! -d /sys/class/net/$IFACE ]; then
   brctl addbr $IFACE || exit 1
